@@ -9,12 +9,10 @@ package Data::Random;
 ################################################################################
 # - Modules and Libraries
 ################################################################################
-use strict;
-use warnings;
 use 5.005_62;
 
 use Carp qw(cluck);
-use Time::Piece;
+
 #use Data::Random::WordList;
 
 require Exporter;
@@ -49,7 +47,7 @@ use vars qw(
 @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 @EXPORT    = qw();
 
-$Data::Random::VERSION = '0.11_3';
+$Data::Random::VERSION = '0.06';
 
 ################################################################################
 # - Subroutines
@@ -102,7 +100,7 @@ sub rand_words {
         require Data::Random::WordList;
 
         # Create a new wordlist object
-        $wl = Data::Random::WordList->new( wordlist => $options{'wordlist'} );
+        $wl = new Data::Random::WordList( wordlist => $options{'wordlist'} );
     }
 
     # Get the random words
@@ -130,7 +128,6 @@ sub rand_chars {
 
     # Get the options hash
     my %options = @_;
-    my @chars;
 
     # Build named character sets if one wasn't supplied
     if ( ref( $options{'set'} ) ne 'ARRAY' ) {
@@ -167,8 +164,7 @@ sub rand_chars {
         $options{'set'} = \@charset;
     }
 
-    @chars = rand_set(%options);
-    return wantarray ? @chars : join('', @chars);
+    return rand_set(%options);
 }
 
 ################################################################################
@@ -260,41 +256,56 @@ sub rand_date {
     # Get the options hash
     my %options = @_;
 
-    my $min;
-    my $max;
+    # use the Date::Calc module
+    eval q{ use Date::Calc };
+
+    cluck($@) && return if $@;
+
+    my ( $min_year, $min_month, $min_day, $max_year, $max_month, $max_day );
+
     # Get today's date
-    my $t = localtime;
-    my ( $year, $month, $day ) = split('-', $t->ymd);
-    my $today = Time::Piece->strptime($t->ymd, "%Y-%m-%d");
+    my ( $year, $month, $day ) = Date::Calc::Today();
 
     if ( $options{'min'} ) {
         if ( $options{'min'} eq 'now' ) {
-            $min = $today;
+            ( $min_year, $min_month, $min_day ) = ( $year, $month, $day );
         }
         else {
-            $min = Time::Piece->strptime($options{'min'}, '%Y-%m-%d');
+            ( $min_year, $min_month, $min_day ) =
+              split ( /\-/, $options{'min'} );
         }
     }
     else {
-        $min = $today;
+        ( $min_year, $min_month, $min_day ) = ( $year, $month, $day );
     }
+
     if ( $options{'max'} ) {
         if ( $options{'max'} eq 'now' ) {
-            $max = $today;
+            ( $max_year, $max_month, $max_day ) = ( $year, $month, $day );
         }
         else {
-            $max = Time::Piece->strptime($options{max}, "%Y-%m-%d");
+            ( $max_year, $max_month, $max_day ) =
+              split ( /\-/, $options{'max'} );
         }
     }
     else {
-          $max = $min->add_years(1);
+        ( $max_year, $max_month, $max_day ) =
+          Date::Calc::Add_Delta_YMD( $min_year, $min_month, $min_day, 1, 0, 0 );
     }
 
-    my $delta_days = int($max->julian_day) - int($min->julian_day);
+    my $delta_days =
+      Date::Calc::Delta_Days( $min_year, $min_month, $min_day, $max_year,
+        $max_month, $max_day, );
+
     cluck('max date is later than min date') && return if $delta_days < 0;
 
-    my $result = $min + ( 3600 * 24  * int( rand($delta_days + 1) ) );
-    return $result->ymd;
+    $delta_days = int( rand( $delta_days + 1 ) );
+
+    ( $year, $month, $day ) =
+      Date::Calc::Add_Delta_Days( $min_year, $min_month, $min_day,
+        $delta_days );
+
+    return sprintf( "%04u-%02u-%02u", $year, $month, $day );
 }
 
 ################################################################################
@@ -379,54 +390,79 @@ sub rand_datetime {
     # Get the options hash
     my %options = @_;
 
+    # use the Date::Calc module
+    eval q{ use Date::Calc };
+
+    cluck($@) && return if $@;
+
+    my (
+        $min_year, $min_month, $min_day, $min_hour, $min_min, $min_sec,
+        $max_year, $max_month, $max_day, $max_hour, $max_min, $max_sec
+    );
+
     # Get today's date
-    my $now = localtime;
-    my $minimum;
-    my $maximum;
+    my ( $year, $month, $day, $hour, $min, $sec ) = Date::Calc::Today_and_Now();
 
-    if ( $options{min} ) {
-        if ( $options{min} eq 'now' ) {
-            $minimum = Time::Piece->strptime(
-              $now->strftime('%Y-%m-%d %H:%M:%S'),
-              '%Y-%m-%d %H:%M:%S'
-            );
+    if ( $options{'min'} ) {
+        if ( $options{'min'} eq 'now' ) {
+            ( $min_year, $min_month, $min_day,
+              $min_hour, $min_min,   $min_sec )
+              = ( $year, $month, $day, $hour, $min, $sec );
         }
         else {
-            $minimum = Time::Piece->strptime(
-              $options{min},
-              '%Y-%m-%d %H:%M:%S'
-            );
+            ( $min_year, $min_month, $min_day,
+              $min_hour, $min_min,   $min_sec )
+              = $options{'min'} =~ /^(\d+)-(\d+)-(\d+) (\d+):(\d+):(\d+)$/;
         }
     }
     else {
-        $minimum = $now;
+        ( $min_year, $min_month, $min_day, $min_hour, $min_min, $min_sec ) =
+          ( $year, $month, $day, 0, 0, 0 );
     }
 
-    if ( $options{max} ) {
-        if ( $options{max} eq 'now' ) {
-            $maximum = Time::Piece->strptime(
-              $now->strftime('%Y-%m-%d %H:%M:%S'),
-              '%Y-%m-%d %H:%M:%S'
-            );
+    if ( $options{'max'} ) {
+        if ( $options{'max'} eq 'now' ) {
+            ( $max_year, $max_month, $max_day,
+              $max_hour, $max_min,   $max_sec )
+              = ( $year, $month, $day, $hour, $min, $sec );
         }
         else {
-            $maximum = Time::Piece->strptime(
-              $options{max},
-              '%Y-%m-%d %H:%M:%S'
-            );
+            ( $max_year, $max_month, $max_day,
+              $max_hour, $max_min,   $max_sec )
+              = $options{'max'} =~ /^(\d+)-(\d+)-(\d+) (\d+):(\d+):(\d+)$/;
         }
     }
     else {
-        $maximum = $minimum->add_years(1);
+        ( $max_year, $max_month, $max_day, $max_hour, $max_min, $max_sec ) =
+          ( Date::Calc::Add_Delta_YMD( $min_year, $min_month, $min_day, 1, 0,
+              0 ), 23, 59, 59 );
     }
 
-    my $delta_secs = $maximum - $minimum;
-    cluck('max_date is later than min date') && return if $delta_secs < 0;
+    my ( $delta_days, $delta_hours, $delta_mins, $delta_secs ) =
+      Date::Calc::Delta_DHMS(
+        $min_year, $min_month, $min_day, $min_hour, $min_min, $min_sec,
+        $max_year, $max_month, $max_day, $max_hour, $max_min, $max_sec,
+    );
+
+    cluck('max date is later than min date') && return
+      if ( $delta_days < 0 ) || ( $delta_hours < 0 ) || ( $delta_mins < 0 )
+      || ( $delta_secs < 0 );
+
+    $delta_secs =
+      ( $delta_days * 86400 ) + ( $delta_hours * 3600 ) + ( $delta_mins * 60 ) +
+      $delta_secs;
+
     $delta_secs = int( rand( $delta_secs + 1 ) );
 
-    my $result = $minimum + $delta_secs;
+    ( $year, $month, $day, $hour, $min, $sec ) = Date::Calc::Add_Delta_DHMS(
+        $min_year, $min_month, $min_day, $min_hour,
+        $min_min,  $min_sec,   0,        0,
+        0,         $delta_secs
+    );
 
-    return $result->strftime('%Y-%m-%d %H:%M:%S');
+    return
+      sprintf( "%04u-%02u-%02u %02u:%02u:%02u", $year, $month, $day, $hour,
+        $min, $sec );
 }
 
 ################################################################################
@@ -437,9 +473,6 @@ sub rand_image {
     # Get the options hash
     my %options = @_;
 
-    eval q{ require GD; };
-    cluck($@) && return if $@;
-
     $options{'minwidth'} ||= 1;
     $options{'maxwidth'} ||= 100;
     $options{'width'} ||=
@@ -461,7 +494,11 @@ sub rand_image {
     $options{'bgcolor'} ||= _color();
     $options{'fgcolor'} ||= _color();
 
-    my $image = GD::Image->new( $options{'width'}, $options{'height'} );
+    eval q{ use GD; };
+
+    cluck($@) && return if $@;
+
+    my $image = new GD::Image( $options{'width'}, $options{'height'} );
 
     my $bgcolor = $image->colorAllocate( @{ $options{'bgcolor'} } );
     my $fgcolor = $image->colorAllocate( @{ $options{'fgcolor'} } );
@@ -478,7 +515,7 @@ sub rand_image {
     return $image->png();
 
     sub _color {
-        return [ int( rand(256) ), int( rand(256) ), int( rand(256) ) ];
+        return [ int( rand(266) ), int( rand(266) ), int( rand(266) ) ];
     }
 }
 
@@ -511,7 +548,6 @@ Data::Random - Perl module to generate random data
   my @random_words = rand_words( size => 10 );
 
   my @random_chars = rand_chars( set => 'all', min => 5, max => 8 );
-  my $string       = rand_chars( set => 'all', min => 5, max => 8 );
 
   my @random_set = rand_set( set => \@set, size => 5 );
 
@@ -523,10 +559,10 @@ Data::Random - Perl module to generate random data
 
   my $random_datetime = rand_datetime();
 
-  open(my $file, ">", "rand_image.png") or die $!;
-  binmode($file);
-  print $file rand_image( bgcolor => [0, 0, 0] );
-  close($file);
+  open(FILE, ">rand_image.png") or die $!;
+  binmode(FILE);
+  print FILE rand_image( bgcolor => [0, 0, 0] );
+  close(FILE);
 
 
 =head1 DESCRIPTION
@@ -567,10 +603,7 @@ shuffle - whether or not the words should be randomly shuffled.  Set this to 0 i
 
 =head2 rand_chars()
 
-When called in a list context this returns
-a list of random characters given a set of characters.
-In a scalar context it returns a string of random characters.
-See below for possible parameters.
+This returns a list of random characters given a set of characters.  See below for possible parameters.
 
 =over 4
 
@@ -795,7 +828,7 @@ fgcolor - the foreground color of the image.  The value must be a reference to a
 
 =head1 VERSION
 
-0.11_3
+0.06
 
 
 =head1 AUTHOR
@@ -809,14 +842,11 @@ Currently maintained by: Buddy Burden (barefoot@cpan.org), starting with version
 
     Hiroki Chalfant
     David Sarno
-	Michiel Beijen
 
 
 =head1 COPYRIGHT
 
-Copyright (c) 2000-2011 Adekunle Olonoh.
-Copyright (c) 2011-2015 Buddy Burden.
-All rights reserved.  This program is free software; you
+Copyright (c) 2000-2011 Adekunle Olonoh.  All rights reserved.  This program is free software; you
 can redistribute it and/or modify it under the same terms as Perl itself.
 
 
